{ config, pkgs, ... }:

{
  # Home Manager needs a bit of information about you and the
  # paths it should manage.
  home.username = "tsv";
  home.homeDirectory = "/home/tsv";

  # This value determines the Home Manager release that your
  # configuration is compatible with. This helps avoid breakage
  # when a new Home Manager release introduces backwards
  # incompatible changes.
  #
  # You can update Home Manager without changing this value. See
  # the Home Manager release notes for a list of state version
  # changes in each release.
  home.stateVersion = "22.11";

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  nixpkgs.config.allowUnfree = true;

  home.packages = with pkgs; [
    firefox
    git-crypt
    gnupg
    delta                                  # Nice diffing pager for Git
    docker-compose
    ruby_3_1
    rubyPackages_3_1.dip
    calibre
    thunderbird
    anki
    htop
    fzf
    gitflow
    gimp
    slack
    spotify
    wine
    winetricks
  ];

  programs.git = {
    enable = true;
    userName = "Trevor Vallender";
    userEmail = "trevor@tsvallender.co.uk";
    aliases = {
      aa = "add -A";
      cm = "commit";
      pf = "push --force";
    };
  };

  home.file = {
    ".tmux.conf".text = ''
      set-option -g prefix C-o
      unbind-key C-b
      bind-key C-o last-window
    '';
  };
  xdg.configFile."nvim/init.vim".source = ./nvim/init.vim;
  home.file.".ssh/config".source = ./ssh/config;

  services.syncthing.enable = true;
  services.syncthing.tray = {
    enable = true;
  };
}
